/* Any copyright is dedicated to the Public Domain.
   http://creativecommons.org/publicdomain/zero/1.0/ */

"use strict";

/* global __dirname */

const sharedJestConfig = require(`${__dirname}/../../../shared/test-helpers/shared-jest.config`);

module.exports = {
  ...sharedJestConfig,
};
